@@ -1,4 +1,4 @@
-#![cfg_attr(RUSTC_WITH_SPECIALIZATION, feature(specialization))]
+#![cfg_attr(RUSTC_WITH_SPECIALIZATION, feature(min_specialization))]
 #![allow(clippy::integer_arithmetic)]
 use solana_sdk::genesis_config::GenesisConfig;
 
@@ -6,7 +6,7 @@ pub mod config;
 pub mod stake_instruction;
 pub mod stake_state;
 
-pub use solana_sdk::stake::program::{check_id, id};
+solana_sdk::declare_id!("Stake11111111111111111111111111111111111111");
 
 pub fn add_genesis_accounts(genesis_config: &mut GenesisConfig) -> u64 {
     config::add_genesis_account(genesis_config)
